# Model
Defines the MetaRisk Model Infrastructure

## Some Considerations
 1. Make sure that the Model repository is editable by all users: `chmod -R o+w Model`

## Uploading to PyPi
 1. Change to the parent directory: `cd /PATH/TO/Model/`
 2. Activate any valid environment (typically `pyModel`)
 3. Build: `python -m build`
 4. Upload using twine: 
    ```bash
    twine check dist/*
    twine upload --verbose dist/*
    ```
